[PATCH v7 8/8] emacs: A prefix argument to `notmuch-show' should invert the matching message behaviour.

2012-02-06 Thread David Edmondson
Allow the user to open a thread with inverted
`notmuch-show-only-matching-messages' behaviour using a prefix
argument.
---
 emacs/notmuch-show.el |5 -
 1 files changed, 4 insertions(+), 1 deletions(-)

diff --git a/emacs/notmuch-show.el b/emacs/notmuch-show.el
index 8c24f38..9c1d8fc 100644
--- a/emacs/notmuch-show.el
+++ b/emacs/notmuch-show.el
@@ -1034,8 +1034,11 @@ function is used."
 ;; buffer.
 (setq notmuch-show-process-crypto notmuch-crypto-process-mime)
 ;; Set the default value for
 ;; `notmuch-show-elide-non-matching-messages' in this buffer.
 (setq notmuch-show-elide-non-matching-messages 
notmuch-show-only-matching-messages)
+(if current-prefix-arg
+   (setq notmuch-show-elide-non-matching-messages (not 
notmuch-show-elide-non-matching-messages)))

 (setq notmuch-show-thread-id thread-id
@@ -1034,8 +1034,11 @@ function is used."
 (setq notmuch-show-process-crypto notmuch-crypto-process-mime)
 ;; Set the default value for
-;; `notmuch-show-elide-non-matching-messages' in this buffer.
+;; `notmuch-show-elide-non-matching-messages' in this buffer. If
+;; there is a prefix argument, invert the default.
 (setq notmuch-show-elide-non-matching-messages 
notmuch-show-only-matching-messages)
  notmuch-show-parent-buffer parent-buffer
-- 
1.7.8.3



[PATCH v7 8/8] emacs: A prefix argument to `notmuch-show' should invert the matching message behaviour.

2012-02-06 Thread David Edmondson
Allow the user to open a thread with inverted
`notmuch-show-only-matching-messages' behaviour using a prefix
argument.
---
 emacs/notmuch-show.el |5 -
 1 files changed, 4 insertions(+), 1 deletions(-)

diff --git a/emacs/notmuch-show.el b/emacs/notmuch-show.el
index 8c24f38..9c1d8fc 100644
--- a/emacs/notmuch-show.el
+++ b/emacs/notmuch-show.el
@@ -1034,8 +1034,11 @@ function is used.
 ;; buffer.
 (setq notmuch-show-process-crypto notmuch-crypto-process-mime)
 ;; Set the default value for
 ;; `notmuch-show-elide-non-matching-messages' in this buffer.
 (setq notmuch-show-elide-non-matching-messages 
notmuch-show-only-matching-messages)
+(if current-prefix-arg
+   (setq notmuch-show-elide-non-matching-messages (not 
notmuch-show-elide-non-matching-messages)))
 
 (setq notmuch-show-thread-id thread-id
@@ -1034,8 +1034,11 @@ function is used.
 (setq notmuch-show-process-crypto notmuch-crypto-process-mime)
 ;; Set the default value for
-;; `notmuch-show-elide-non-matching-messages' in this buffer.
+;; `notmuch-show-elide-non-matching-messages' in this buffer. If
+;; there is a prefix argument, invert the default.
 (setq notmuch-show-elide-non-matching-messages 
notmuch-show-only-matching-messages)
  notmuch-show-parent-buffer parent-buffer
-- 
1.7.8.3

___
notmuch mailing list
notmuch@notmuchmail.org
http://notmuchmail.org/mailman/listinfo/notmuch